__version__ = "0.6.0"

from .wildewidgets import (
    AltairChart,
    BarChart, 
    BasicMenu,
    DoughnutChart,
    Histogram,
    HorizontalBarChart, 
    HorizontalHistogram,
    HorizontalStackedBarChart,
    LightMenu,
    MenuMixin,
    PieChart,
    StackedBarChart, 
    TemplateWidget,
    WildewidgetDispatch,
)

from .tables import (
    BasicModelTable,
    DataTable,
    DataTableFilter,
)

from .views import (
    TableActionFormView,
)